/***********************************************************************************
 *                                                                         										*
 *   This program is free software; you can redistribute it and/or modify       *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or         *
 *   (at your option) any later version.                                   							*
 *                                                                         										*
 ************************************************************************************/

#ifndef XSLDBGMSGDIALOGIMPL_H
#define XSLDBGMSGDIALOGIMPL_H

/**
  *@author Keith Isdale
  */

#include "ui_xsldbgmsgdialog.h"

class XsldbgMsgDialogImpl : public QDialog, Ui::XsldbgMsgDialog {

public:

  XsldbgMsgDialogImpl(QWidget *parent,
		      QMessageBox::Icon icon, 
		      const QString & title, const QString &msg);

  void append(const QString &text);
};

#endif // XSLDBGMSGDIALOGIMPL_H
